@@ -7,7 +7,12 @@ from textwrap import dedent, wrap
 
 from . import conf
 
-def make_tmp_file(fname, mode='w'):
+def make_open_tmp_file(fname, mode='w'):
+    """
+    Note - file needs to be closed for changes to be saved to the file -
+    otherwise it will be 0 bytes. Up to client code to ensure it is closed and
+    properly available for subsequent steps.
+    """
     tmp_fh = tempfile.NamedTemporaryFile(mode=mode, delete=False)
     randomly_named_fpath = Path(tmp_fh.name)
     fpath = Path(randomly_named_fpath.parent) / fname
@@ -58,6 +63,10 @@ def int2nice(num):
     return nice.get(num, num)
 
 def layout_comment(raw_comment, *, is_code=False):
+    """
+    Don't break up long lines which are titles otherwise the subsequent parts
+    won't carry appropriate heading-level formatting.
+    """
     if '`' in raw_comment and is_code:
         logging.debug("Backtick detected in code which is probably a mistake")
     if is_code:
@@ -80,7 +89,10 @@ def layout_comment(raw_comment, *, is_code=False):
                 len(raw_paragraph) - len(raw_paragraph.rstrip('\n')))
             paragraph = raw_paragraph.strip()
             one_line_paragraph = paragraph.replace('\n', ' ')  ## actually continuations of same line so no need to put on separate lines
-            wrapped_paragraph_lines = wrap(one_line_paragraph)
+            if one_line_paragraph.startswith('#'):
+                wrapped_paragraph_lines = [one_line_paragraph, ]
+            else:
+                wrapped_paragraph_lines = wrap(one_line_paragraph)
             new_paragraph = (
                 (n_start_new_lines * '\n\n')
                 + '\n'.join(wrapped_paragraph_lines)
